@@ -11,16 +11,13 @@ use List::MoreUtils qw(none);
 use Readonly;
 
 # Version.
-our $VERSION = 0.21;
+our $VERSION = 0.22;
 
 # Constants.
 Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 Readonly::Scalar my $EMPTY_STR => q{};
 
-# Ignore die signal.
-$SIG{__DIE__} = 'IGNORE';
-
 # Process error.
 sub err {
 	my @msg = @_;
@@ -184,11 +181,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © Michal Špaček 2008-2014
+ © 2008-2014 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.21
+0.22
 
 =cut
