@@ -16,10 +16,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.21;
-
-# Ignore die signal.
-$SIG{__DIE__} = 'IGNORE';
+our $VERSION = 0.22;
 
 # Process error.
 sub err {
@@ -157,11 +154,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © Michal Špaček 2008-2014
+ © 2008-2014 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.21
+0.22
 
 =cut
